@@ -5,9 +5,15 @@ from .enums import (
     PaymentSource,
     OperationType,
     RecipientType,
+    NotificationType
+)
+from .operation import Operation
+from .operation_history import (
+    OperationHistory,
+    OperationHistoryParams
 )
 from .operation_details import OperationDetails
-from .operation_history import Operation, OperationHistory, OperationHistoryParams
 from .account_info import AccountInfo
 from .payment import PaymentForm
+from .notification import NotificationBase, NotificationExtend
 
