@@ -74,7 +74,8 @@ class YooMoneyWallet(_BaseWallet):
         super().__init__(access_token, headers)
         self.client = Client(
             base_url=self.BASE_URL,
-            headers=self._headers
+            headers=self._headers,
+            follow_redirects=True
         )
 
     def __enter__(self) -> Self:
@@ -112,7 +113,7 @@ class YooMoneyWallet(_BaseWallet):
 
     def create_payment_form(
             self,
-            amount_rub: int,
+            amount_rub: int | float,
             unique_label: str,
             success_redirect_url: str | None = None,
             payment_source: PaymentSource = PaymentSource.BANK_CARD
@@ -122,7 +123,7 @@ class YooMoneyWallet(_BaseWallet):
         params = {
             "receiver": account_info.account,
             "quickpay-form": "button",
-            "paymentType": payment_source,
+            "paymentType": payment_source.value,
             "sum": amount_rub,
             "successURL": success_redirect_url,
             "label": unique_label
@@ -147,7 +148,8 @@ class YooMoneyWalletAsync(_BaseWallet):
         super().__init__(access_token, headers)
         self.client = AsyncClient(
             base_url=self.BASE_URL,
-            headers=self._headers
+            headers=self._headers,
+            follow_redirects=True
         )
 
     async def __aenter__(self) -> Self:
@@ -185,7 +187,7 @@ class YooMoneyWalletAsync(_BaseWallet):
 
     async def create_payment_form(
             self,
-            amount_rub: int,
+            amount_rub: int | float,
             unique_label: str,
             success_redirect_url: str | None = None,
             payment_source: PaymentSource = PaymentSource.BANK_CARD
@@ -195,7 +197,7 @@ class YooMoneyWalletAsync(_BaseWallet):
         params = {
             "receiver": account_info.account,
             "quickpay-form": "button",
-            "paymentType": payment_source,
+            "paymentType": payment_source.value,
             "sum": amount_rub,
             "successURL": success_redirect_url,
             "label": unique_label
